### Images

Add an image by dragging it from Finder onto a glyph cell.
The image will be added to the currently active layer.
Alternatively, choose “Glyph” → “Add Image…” to insert an image file to the selected glyph.

Add images to multiple glyphs at once by choosing “Glyph” → “Add Image…” and then selecting multiple image files.
The images will be placed on the layer of the current master of the glyphs that correspond to an image name.
For example, `Thorn.png` is added to the glyph Thorn, and `Dje-cy.jpeg` is added to Dje-cy.

Note that while glyph names are case-_sensitive_ (A is different from a), file names on macOS are case-_insensitive_ by default (`A.png` is considered the same file name as `a.png`).
Uppercase and lowercase files thus cannot coexist in the same folder.
As a workaround, place images for uppercase letters in a different folder than lowercase letters.

Images are shown in Font View when “View” → “Show Image” is selected.
If a glyph is empty (no paths or components are placed in the glyph), the image is displayed regardless of the “Show Image” option.
See Edit View: Images for information on working with images in Edit View.